@@ -1,8 +1,8 @@
-#' Creates a coalescent model
+#' Create a Coalescent Model
 #'
 #' This creates a basic coalescent model to which more features, loci,
-#' parameters and summary statistics can be added. Data under the model
-#' can be simulated using the \code{simulate} function.
+#' parameters and summary statistics can be added later. Data under the model
+#' can be simulated using the \code{\link[=simulate.coalmodel]{simulate}} function.
 #'
 #' @inheritParams feat_sample
 #' @param sample_size Defines the number of populations and the number of
@@ -12,17 +12,48 @@
 #' @param loci_number You can optionally add a number of loci with equal length
 #'   to the model. This gives to number of loci to add.
 #' @param loci_length This gives the length of the loci to add.
-#' @return The coalescent model
+#' @return The basic coalescent model which can be extended with features,
+#'   parameters, loci and summary statistics.
 #' @export
+#' @seealso The 'coala-intro' vignette for a general description on how to extend
+#'          models.
+#' @seealso For checking which simulators can be used for this model:
+#'          \code{\link{check_model}}
+#' @seealso For adding mutation or for a list of other features:
+#'          \code{\link{feat_mutation}}
+#' @seealso For adding loci: \code{\link{locus_single}},
+#'          \code{\link{locus_averaged}}, \code{\link{locus_trio}}
+#' @seealso For a generating DNA sequences or for a list of summary statistics:
+#'          \code{\link{sumstat_dna}}
 #' @importFrom assertthat assert_that
 #' @examples
-#' model <- coal_model(5, 10, 100) + feat_mutation(1) + sumstat_sfs()
+#' # A model with one population and 20 unlinked loci:
+#' model <- coal_model(10, 20) +
+#'   feat_mutation(5) +
+#'   sumstat_tajimas_d()
+#' check_model(model)
 #' simulate(model)
 #'
-#' model <- coal_model(c(2, 2), 1, 10) +
-#'   feat_recombination(1) +
-#'   feat_migration(0.5, symmetric = TRUE) +
+#' # A model with two populations:
+#' model <- coal_model(c(13, 18), 5) +
+#'   feat_migration(.5, symmetric = TRUE) +
 #'   sumstat_trees()
+#' check_model(model)
+#' simulate(model)
+#'
+#' # A model with 10 populations:
+#' model <- coal_model(rep(2, 10), 5) +
+#'   feat_migration(.5, symmetric = TRUE) +
+#'   sumstat_trees()
+#' check_model(model)
+#' simulate(model)
+#'
+#' # A model with recombination:
+#' model <- coal_model(20, 1, 1000) +
+#'   feat_recombination(10) +
+#'   feat_mutation(5) +
+#'   sumstat_four_gamete()
+#' check_model(model)
 #' simulate(model)
 coal_model <- function(sample_size, loci_number = 0,
                        loci_length = 1000, ploidy = 1) {
@@ -35,7 +66,7 @@ coal_model <- function(sample_size, loci_number = 0,
                 scaling_factor = 1,
                 id = get_id())
 
-  class(model) <- c("coalmodel")
+  class(model) <- c("coalmodel", "coalmodelpart")
 
   # Add sample sizes
   model <- model + feat_sample(sample_size, ploidy)
@@ -53,6 +84,8 @@ is.model <- function(model) {
   "coalmodel" %in% class(model)
 }
 
+model_part <- R6Class("coalmodelpart")
+
 
 # Selects a program for simulation that is capable of all current features
 select_simprog <- function(model) {
