@@ -3,11 +3,32 @@
 #' @param e1 The Model to which the feature/parameter should be added
 #' @param e2 The feature/parameter to add
 #' @return The extended model
-"+.coalmodel" <- function(e1, e2) {
-  e2name <- deparse(substitute(e2)) # Passed throw for error messages
-  add_to_model(e2, e1, e2name)
+#' @keywords internal
+"+.coalmodelpart" <- function(e1, e2) {
+  e2name <- deparse(substitute(e2)) # Passed through for error messages
+
+  if (is.model(e1)) return(add_to_model(e2, e1, e2name))
+
+  if (is_partial_model(e1)) {
+    e1[[length(e1) + 1]] <- e2
+    return(e1)
+  }
+
+  partial_model <- list(e1, e2)
+  class(partial_model) <- c("partial_model", "coalmodelpart")
+  partial_model
 }
 
+is_partial_model <- function(x) inherits(x, "partial_model")
+
+#' @export
+print.partial_model <- function(x, ...) {
+  cat("Partial coal_model with ", length(x), " components:\n")
+  for (part in x) {
+    cat("* ")
+    print(part)
+  }
+}
 
 add_to_model <- function(x, model, x_name) UseMethod("add_to_model")
 add_to_model.default <- function(x, model, x_name) {
@@ -65,3 +86,11 @@ add_to_model.locus <- function(locus, model, locus_name) {
   model$id <- get_id()
   model
 }
+
+
+add_to_model.partial_model <- function(partial_model, model, partical_name) {
+  for (part in partial_model) {
+    model <- model + part
+  }
+  model
+}
