@@ -1,7 +1,8 @@
 # Base class for all parameters.
 # Contains an expression that can be assigned to some part of a feature.
+#' @include model.R
 #' @importFrom R6 R6Class
-parameter_class <- R6Class("parameter",
+parameter_class <- R6Class("parameter", inherit = model_part,
   private = list(expr = NA),
   public = list(
     initialize = function(expr) {
@@ -59,39 +60,72 @@ is.named_par <- function(par) {
 }
 
 
-#' Define Model parameters
+#' Model Parameters
 #'
-#' This functions allow to add parameters to a model. parameters can either
+#' These functions add parameters to a model. Parameters can either
 #' be used in features, or added directly to a model using the plus operator.
 #' The value of parameters can be specified in the simulation command
 #' (for \code{par_named} and \code{par_range}), sampled from a prior
 #' distribution (\code{par_prior}) or can be derived from other parameters
 #' (\code{par_expr}).
 #'
+#' @name parameter
+#' @seealso For parameters that variate between the loci in a model:
+#'   \code{\link{par_variation}}, \code{\link{par_zero_inflation}}
+#' @author Paul Staab
+#' @examples
+#' # A parameter (here for the mutation rate) that is always
+#' # equal to '5':
+#' model_base <- coal_model(20, 1) +
+#'   sumstat_nucleotide_div()
+#'
+#' model <- model_base +
+#'   feat_mutation(par_const(5))
+#' simulate(model)
+#'
+#' # With using a prior:
+#' model <- model_base +
+#'   feat_mutation(par_prior("theta", rnorm(1, 5, .1)))
+#' simulate(model)
+#'
+#' # Using a named parater:
+#' model <- model_base +
+#'   feat_mutation(par_named("theta"))
+#' simulate(model, pars = c(theta = 5))
+#'
+#' # or similarly a ranged parameter:
+#' model <- model_base +
+#'   feat_mutation(par_range("theta", 1, 10))
+#' simulate(model, pars = c(theta = 5))
+#'
+#' # Expressions can be used to derive parameters from
+#' # other parameters:
+#' model <- model_base +
+#'   par_named("theta_half") +
+#'   feat_mutation(par_expr(theta_half * 2))
+#' simulate(model, pars = c(theta_half = 2.5))
+#'
+#' model <- model_base +
+#'   par_named("theta_log") +
+#'   feat_mutation(par_expr(exp(theta_log)))
+#' simulate(model, pars = c(theta_log = log(5)))
+NULL
+
+#' @describeIn parameter Creates a parameter with value determined by evaluating an expression.
 #' @param expr An R expression.
 #'  This allows to define a parameter using an R expression.
 #'  It can contain other named parameters (e.g. \code{2 * a} will create an
 #'  parameter that is twice the value of an existing parameter \code{a}).
 #'  Make sure that the expression always evaluates
 #'  to a valid parameter value (a single numeric in almost all cases).
-#' @describeIn par_expr Creates a parameter with value determined by evaluating an
-#'  expression.
 #' @export
-#' @aliases parameter
-#' @author Paul Staab
-#' @examples
-#' par_const(5)
-#' par_named("x")
-#' par_prior("y", rnorm(1))
-#' par_range("z", 1, 5)
-#' par_expr(2*x + y * z)
 par_expr <- function(expr) {
   parameter_class$new(as.expression(substitute(expr)))
 }
 
 
-#' @describeIn par_expr Creates an parameter that is equal to a fixed value.
-#'   Different to par_expr, the value is evaluated on parameter creation.
+#' @describeIn parameter Creates an parameter that is equal to a fixed value.
+#'   Different to \code{par_expr}, the value is evaluated on parameter creation.
 #' @export
 #' @param constant An R expression.
 #'   The constant value of the parameter.
@@ -102,7 +136,7 @@ par_const <- function(constant) {
 }
 
 
-#' @describeIn par_expr Creates an parameter whose value is specified via the
+#' @describeIn parameter Creates an parameter whose value is specified via the
 #'   \code{pars} argument in \code{\link{simulate.coalmodel}}.
 #' @export
 #' @param name Character. The name of the parameter. Must be unique in a model.
@@ -144,7 +178,7 @@ range_par_class <- R6Class("range_par", inherit = named_par_class,
 is.ranged_par <- function(par) inherits(par, "range_par")
 
 
-#' @describeIn par_expr Creates an parameter that can take a range of possible
+#' @describeIn parameter Creates an parameter that can take a range of possible
 #'  values.
 #'  Similar to \code{\link{par_named}}, the value of the parameter
 #'  used in a simulation is set via the \code{pars} argument.
@@ -152,8 +186,8 @@ is.ranged_par <- function(par) inherits(par, "range_par")
 #'  \pkg{jaatha}.
 #'
 #' @export
-#' @param lower A numeric. The lower boundary of the parameter"s range.
-#' @param upper A numeric. The upper boundary of the parameter"s range.
+#' @param lower A numeric. The lower boundary of the parameter's range.
+#' @param upper A numeric. The upper boundary of the parameter's range.
 par_range <- function(name, lower, upper) {
   range_par_class$new(lower, upper, name)
 }
