@@ -3,8 +3,10 @@
 #' If you want to create additional summary statistics for coala, create
 #' \pkg{R6} classes that inherit from this object.
 #'
+#' @include model.R
+#' @keywords internal
 #' @export
-sumstat_class <- R6Class("sumstat",
+sumstat_class <- R6Class("sumstat", inherit = model_part,
   private = list(
     name = NA,
     req_files = FALSE,
@@ -144,16 +146,27 @@ calc_sumstats_from_sim <- function(seg_sites, trees, files, model,
 #'   to specify additional argument for the conversion using the \code{...}
 #'   argument.
 #' @param tree_list Not yet implemented.
-#' @param trios If your model is using locus trios, then you need
+#' @param trios If your model is using locus trios, then you
 #'   can create these by combining individual loci. This is a list that defines
 #'   which loci are combined to a trio. Each entry should consist of either
 #'   one or three numbers. For one number, the locus used for calculating the
 #'   summary statistics is locus in the provided data that corresponds to the
-#'   number. If three number are provided, the locus for calculation is created
+#'   number. If three numbers are provided, the locus for calculation is created
 #'   by combining the corresponding three loci from the given data.
-#' @param ... Additional arguments that will be pass to
+#' @param ... Additional arguments that will be passed to
 #'   \code{\link{as.segsites}}.
 #' @export
+#' @examples
+#' segsites <- create_segsites(matrix(c(1, 0, 0,
+#'                                      1, 1, 0,
+#'                                      0, 0, 1), 3, 3, TRUE),
+#'                             c(.1, .3, .5))
+#' model <- coal_model(3, 1) +
+#'   sumstat_sfs() +
+#'   sumstat_nucleotide_div() +
+#'   sumstat_mcmf()
+#' sumstats <- calc_sumstats_from_data(model, list(segsites))
+#' print(sumstats)
 calc_sumstats_from_data <- function(model,
                                     segsites_list = NULL,
                                     tree_list = NULL,
